@@ -19,6 +19,9 @@ OC.L10N.register(
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari pòdon ara utilizar la conversacion àudio e vidèo",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Podètz ara notificar totes los participants en publicant « @all » al chat",
     "- You can now mention guests in the chat" : "- Podètz ara mencionar los convidats al chat",
+    "There are currently no commands available." : "Cap de comanda pas disponibla pel moment.",
+    "The command does not exist" : "La comanda existís pas",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "Una error s’es producha en executant la comanda. Volgatz demandar a l’administrator de verificar los jornals.",
     "Talk updates ✅" : "Mesas a jorn Talk ✅",
     "{actor} created the conversation" : "{actor} a creat la conversacion",
     "You created the conversation" : "Avètz creat la conversacion",
@@ -47,9 +50,12 @@ OC.L10N.register(
     "{actor} limited the conversation to the current participants" : "{actor} a limitat la conversacion als participants actuals",
     "You limited the conversation to the current participants" : "Avètz limitat la conversacion als participants actuals",
     "An administrator limited the conversation to the current participants" : "Un administrator a limitat la conversacion als participants actuals",
+    "{actor} opened the conversation to registered users" : "{actor} dobriguèt la conversacion als utilizaires enregistrats",
     "You opened the conversation to registered users" : "Dobriretz la conversacion als utilizaires enregistrats",
     "An administrator opened the conversation to registered users" : "Un administrator dobriguèt la conversacion als utilizaires enregistrats",
     "{actor} opened the conversation to registered and guest app users" : "{actor} dobriguèt la conversacion als utilizaires enregistrats",
+    "You opened the conversation to registered and guest app users" : "Avètz dobèrt la conversacion als utilizaires enregistrats e als convidats",
+    "An administrator opened the conversation to registered and guest app users" : "Un administrator dobriguèt la conversacion als utilizaires enregistrats e als convidats",
     "The conversation is now open to everyone" : "La conversacion es ara dubèrta a tot lo monde",
     "{actor} opened the conversation to everyone" : "{actor} a dubèrta la conversacion a tot lo monde",
     "You opened the conversation to everyone" : "Avètz dobèrta la conversacion a tot lo monde",
@@ -79,17 +85,20 @@ OC.L10N.register(
     "{actor} removed you" : "{actor} vos a levat",
     "An administrator removed you" : "Un administrator vos a levat",
     "An administrator removed {user}" : "Un administrator a tirat {user}",
+    "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
     "{actor} deleted a message" : "{actor} a suprimit un messatge",
     "You deleted a message" : "Avètz suprimit un messatge",
     "Message deleted by author" : "Messatge suprimit per son autor",
     "Message deleted by {actor}" : "Messatge suprimit per {actor}",
     "Message deleted by you" : "Messatge suprimit per vos",
     "%s (guest)" : "%s (convidat)",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
     "Talk to %s" : "Parlar a %s",
+    "File is not shared, or shared but not with the user" : "Fichièr pas partejat, o partejat mas pas a l’utilizaire",
     "No account available to delete." : "Cap de compte pas disponible per la supression.",
     "No image file provided" : "Cap de fichièr imatge provesit",
     "File is too big" : "Fichièr tròp pesuc",
@@ -112,9 +121,11 @@ OC.L10N.register(
     "{user} in {call}" : "{user} dins {call}",
     "Deleted user in {call}" : "Utilizaire suprimit dins {call}",
     "{guest} (guest) in {call}" : "{guest} (guest) dins {call}",
+    "Guest in {call}" : "Convidat dins {call}",
     "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
     "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
     "A guest mentioned you in conversation {call}" : "Un convidat vos a mencionat dins la conversacion {call}",
+    "View chat" : "Veire lo chat",
     "Join call" : "Rejónher la sonada",
     "Answer call" : "Respondre a l’apèl",
     "{user} would like to talk with you" : "{user} volriá vos parlar",
@@ -126,11 +137,17 @@ OC.L10N.register(
     "{user}" : "{user}",
     "Messages in {conversation}" : "Messatges dins {conversation}",
     "{user} in {conversation}" : "{user} dins {conversation}",
+    "Messages in other conversations" : "Messatges dins autras conversacions",
+    "Something unexpected happened." : "Quicòm d’inesperat s’es produch.",
     "The URL is invalid." : "L’URL es invalida",
     "An HTTPS URL is required." : "Una URL HTTPS es requerida.",
     "The email address is invalid." : "L’adreça email es invalida.",
     "The language is invalid." : "La lenga es invalida.",
     "The country is invalid." : "Lo país es invalid.",
+    "Too many requests are send from your servers address. Please try again later." : "Tròp de requèstas enviadas de vòstras adreça de servidor. Ensajatz mai tard.",
+    "Something unexpected happened. Please try again later." : "Quicòm d’inesperat s’es produch. Volgatz ensajar mai tard.",
+    "There is no such account registered." : "Cal de tal compte pas enregistrat.",
+    "Too many requests are sent from your servers address. Please try again later." : "Tròp de requèstas enviadas de vòstras adreça de servidor. Ensajatz mai tard.",
     "Andorra" : "Andòrra",
     "United Arab Emirates" : "Emirats Arabis Units",
     "Afghanistan" : "Afganistan",
@@ -371,6 +388,7 @@ OC.L10N.register(
     "South Africa" : "Sudafrica",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
     "Conversation not found" : "Conversacion pas trobada",
     "Chat, video & audio-conferencing using WebRTC" : "Messatjariá, conferéncias vidèo e àudio amb WebRTC",
     "Leave call" : "Quitar la sonada",
@@ -395,16 +413,21 @@ OC.L10N.register(
     "Disabled" : "Desactivat",
     "Moderators" : "Moderators",
     "Users" : "Utilizaires",
+    "Commands" : "Comandas",
     "Beta" : "Bèta",
     "Name" : "Nom",
+    "Command" : "Comanda",
     "Script" : "Escript",
     "Response to" : "Respondre a",
+    "Enabled for" : "Activat per",
     "General settings" : "Paramètres generals",
     "Default notification settings" : "Paramètres de notificacion per defaut",
     "Default group notification" : "Notificacion de grop per defaut",
+    "Allow conversations on files" : "Permetre las conversacions suls fichièrs",
     "All messages" : "Totes los messatges",
     "Off" : "Atudat",
     "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
+    "Email of the user" : "Email de l’utilizaire",
     "Language" : "Lenga",
     "Country" : "País",
     "Status" : "Estatut",
@@ -429,12 +452,14 @@ OC.L10N.register(
     "Delete this server" : "Suprimir aqueste servidor",
     "Status: Checking connection" : "Estat : verificacion de la connexion",
     "OK: Running version: {version}" : "OK : execucion de la version : {version}",
-    "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
+    "Error: Cannot connect to server" : "Error : connexion impossibla al servidor",
+    "Error: Unknown error occurred" : "Error : una error desconeguda s'es produsida",
     "Saved" : "Enregistrat",
     "Add a new server" : "Apondre un servidor novèl",
     "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Es forçadament recomandat de configurar a cache distribuit pendent l’utilizacion de Nextcloud Talk amb un back-end de fòrt rendiment.",
     "STUN server URL" : "URL servidor STUN",
     "STUN servers" : "Servidors STUN",
+    "TURN server schemes" : "Esquèmas servidor TURN",
     "{option1} and {option2}" : "{option1} e {option2}",
     "{option} only" : "{option} sonque",
     "TURN server URL" : "URL servidor TURN",
@@ -453,19 +478,19 @@ OC.L10N.register(
     "Share a single window" : "Partejar sonque una fenèstra",
     "Show your screen" : "Partejar l’ecran",
     "Stop screensharing" : "Arrestar partiment d’ecran",
-    "Lower hand (r)" : "Baissar la man (r)",
+    "Lower hand (R)" : "Baissar la man (R)",
     "More actions" : "Mai d’accions",
     "Settings" : "Paramètres",
     "Dismiss" : "Regetar",
-    "Raise hand (r)" : "Levar la man (r)",
+    "Raise hand (R)" : "Levar la man (R)",
     "No audio" : "Cap d’àudio",
-    "Mute audio (m)" : "Copar lo son (m)",
-    "Unmute audio (m)" : "Restablir lo son (m)",
+    "Mute audio (M)" : "Copar lo son (M)",
+    "Unmute audio (M)" : "Restablir lo son (M)",
     "Mute audio" : "Copar lo son",
     "Unmute audio" : "Restablir lo son",
     "No camera" : "Cap de camèra",
-    "Disable video (v)" : "Desactivar la vidèo (v)",
-    "Enable video (v)" : "Activar la vidèo (v)",
+    "Disable video (V)" : "Desactivar la vidèo (V)",
+    "Enable video (V)" : "Activar la vidèo (V)",
     "Disable video" : "Desactivar la vidèo",
     "Enable video" : "Activar la vidèo",
     "Screensharing options" : "Opcion de partiment d’ecran",
@@ -488,6 +513,7 @@ OC.L10N.register(
     "Stop following" : "Quitar de seguir",
     "Conversation messages" : "Messatges de conversacion",
     "Post message" : "Publicar messatge",
+    "You need to be logged in to upload files" : "Devètz èsser autentificat per enviar de fichièrs",
     "This conversation is read-only" : "Aquesta conversacion es en lectura sola",
     "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
     "Call in progress" : "Sonada en cors",
@@ -510,6 +536,8 @@ OC.L10N.register(
     "Save password" : "Enregistrar lo senhal",
     "Copy conversation link" : "Copiar lo ligam de conversacion",
     "Resend invitations" : "Tornar enviar las invitacions",
+    "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
+    "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
     "Invitations sent" : "Invitacions enviadas",
     "Enable lobby" : "Activar la sala d’espèra",
     "After the time limit the lobby will be automatically disabled." : "Aprèp la limita de temps la sala d’espèra serà automaticament desactivada.",
@@ -531,6 +559,8 @@ OC.L10N.register(
     "Team name" : "Nom de la còla",
     "Channel name" : "Nom de la cadena",
     "Password" : "Senhal",
+    "Bot user name" : "Nom d’utilizaire robòt",
+    "Bot API key" : "Clau d’API robòt",
     "API token" : "Geton API",
     "Channel" : "Cadena",
     "Login" : "Login",
@@ -546,6 +576,9 @@ OC.L10N.register(
     "Tenant ID" : "ID Tenant",
     "Client ID" : "ID client",
     "Team ID" : "ID Team",
+    "Thread ID" : "ID fial",
+    "XMPP/Jabber server URL" : "URL servidor XMPP/Jabber",
+    "MUC server URL" : "URL servidor MUC",
     "Jabber ID" : "ID Jabber",
     "unknown state" : "estat desconegut",
     "running" : "en cors d'execucion",
@@ -590,14 +623,17 @@ OC.L10N.register(
     "No camera available" : "Cap de camèra pas disponibla",
     "Select camera" : "Causir una camèra",
     "Reply" : "Respondre",
+    "Copy message link" : "Copiar ligam messatge",
     "Mark as unread" : "Marcar coma pas legit",
     "Unread messages" : "Messatges pas legits",
     "Sending message" : "Mandadís del messatge",
     "Message sent" : "Messatge mandat",
     "Not enough free space to upload file" : "Pas pro d’espaci liure per enviar lo fichièr",
-    "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
     "Deleting message" : "Supression del messatge",
+    "Message deleted successfully" : "Messatge corrèctament suprimit",
+    "{stack} in {board}" : "{stack} dins {board}",
     "Remove" : "Suprimir",
+    "[Unknown username]" : "[utilizaire desconegut]",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
     "Upload new files" : "Enviar fichièrs novèls",
@@ -610,7 +646,10 @@ OC.L10N.register(
     "Description" : "Descripcion",
     "Disable lobby" : "Desactivar la sala d’espèra",
     "moderator" : "moderator",
+    "bot" : "robòt",
     "guest" : "convidat",
+    "Remove participant" : "Tirar participant",
+    "Settings for participant \"{user}\"" : "Paramètres pel participant « {user} »",
     "Add participant \"{user}\"" : "Apondre participant « {user} »",
     "Participant \"{user}\"" : "Participant « {user} »",
     "Joined with audio" : "Rejonhèt amb l’àudio",
@@ -631,6 +670,8 @@ OC.L10N.register(
     "Chat" : "Messatjariá",
     "Details" : "Detalhs",
     "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
+    "Meeting ID: {meetingId}" : "ID reünion : {meetingId}",
+    "Your PIN: {attendeePin}" : "Vòstre PIN : {attendeePin}",
     "Display name: " : "Nom d’afichatge :",
     "Choose devices" : "Causir periferics",
     "Attachments folder" : "Dossièr de pèças-juntas",
@@ -644,8 +685,11 @@ OC.L10N.register(
     "Shortcuts while in a call" : "Acorchis pendent una sonada",
     "Video on and off" : "Vidèo activada/desactivada",
     "Microphone on and off" : "Microfòn activat/desactivat",
+    "Space bar" : "barra d’espaci",
     "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
     "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
+    "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
+    "Sounds setting saved" : "Paramètres de son enregistrats",
     "Start call" : "Començar sonada",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
     "Conversation actions" : "Accions de conversacion",
@@ -653,28 +697,33 @@ OC.L10N.register(
     "Go to file" : "Anar al fichièr",
     "Rename conversation" : "Renomenar la conversacion",
     "Mute others" : "Copar lo son dels autres",
-    "Exit fullscreen (f)" : "Sortir del ecran complèt (f)",
-    "Fullscreen (f)" : "Ecran complèt (f)",
+    "Exit fullscreen (F)" : "Quitar plen ecran (F)",
+    "Fullscreen (F)" : "Plen ecran (F)",
     "Grid view" : "Vista en grasilha",
     "Send" : "Mandar",
     "Add more files" : "Apondre mai de fichièrs",
+    "No unread mentions" : "Cap de mencion pas legida",
+    "Say hi to your friends and colleagues!" : "Saludatz vòstres amics e collègas !",
     "Start a conversation" : "Començar una conversacion",
     "You were mentioned" : "Qualqu’un vos a mencionat",
     "Message without mention" : "Messatge sens mencion",
+    "Mention myself" : "Me mencionar",
+    "Mention room" : "Mencionar la sala",
     "The conversation does not exist" : "La conversacion existís pas",
     "No conversations found" : "Cap de conversacion pas trobada",
     "Select conversation" : "Seleccionar una conversacion",
     "Link to a conversation" : "Ligam cap a la conversacion",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
+    "Post to a conversation" : "Publicar dins una conversacion",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
     "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
-    "Leave this page" : "Quitar aquesta pagina",
     "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
     "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
+    "Leave this page" : "Quitar aquesta pagina",
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
     "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
     "Camera {number}" : "Camèra {number}",
@@ -699,9 +748,14 @@ OC.L10N.register(
     "New in Talk 9" : "Nòu dins Talk 9",
     "{user} wants to talk with you" : "{user} vòl vos parlar",
     "Signaling server URL" : "URL del servidor de senhalizacion",
+    "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
     "UDP and TCP" : "UDP e TCP",
     "UDP only" : "Sonque UDP",
     "TCP only" : "Sonque TCP",
+    "Mute audio (m)" : "Copar lo son (m)",
+    "Unmute audio (m)" : "Restablir lo son (m)",
+    "Disable video (v)" : "Desactivar la vidèo (v)",
+    "Enable video (v)" : "Activar la vidèo (v)",
     "This conversation is read only" : "La conversacion es en lectura sola",
     "Conversation, " : "Conversacion, ",
     "Default location for attachments" : "Emplaçament per defaut per las pèças juntas",
@@ -712,13 +766,18 @@ OC.L10N.register(
     "Projects" : "Projèctes",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada",
     "Share link" : "Partejar lo ligam",
+    "Exit fullscreen (f)" : "Sortir del ecran complèt (f)",
+    "Fullscreen (f)" : "Ecran complèt (f)",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Error while uploading file" : "Error en enviant lo fichièr",
     "New in Talk 10" : "Nòu dins Talk 10",
     "E-mail of the user" : "E-mail de l’utilizaire",
+    "More info on Matterbridge." : "Mai d‘informacions sus Matterbridge.",
     "Enabled" : "Activada",
+    "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
     "Lower hand" : "Baissar la man",
     "Raise hand" : "Levar la man",
+    "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
     "turn: and turns:" : "turn: e turns:",
     "turn: only" : "turn: sonque",
     "turns: only" : "turns: sonque"
