@@ -228,14 +228,12 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function getListedRooms(string $searchTerm = ''): DataResponse {
-		$event = new UserEvent($this->userId);
-
 		$rooms = $this->manager->getListedRoomsForUser($this->userId, $searchTerm);
 
 		$return = [];
 		foreach ($rooms as $room) {
 			try {
-				$return[] = $this->formatRoomV2andV3($room, null);
+				$return[] = $this->formatRoom($room, null);
 			} catch (RoomNotFoundException $e) {
 			} catch (\RuntimeException $e) {
 			}
@@ -1505,6 +1503,15 @@ class RoomController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
+		if ($state === Room::READ_ONLY) {
+			$participants = $this->participantService->getParticipantsInCall($this->room);
+
+			// kick out all participants out of the call
+			foreach ($participants as $participant) {
+				$this->participantService->changeInCall($this->room, $participant, Participant::FLAG_DISCONNECTED);
+			}
+		}
+
 		return new DataResponse();
 	}
 
