@@ -34,6 +34,7 @@ use OCA\Talk\Events\SignalingRoomPropertiesEvent;
 use OCA\Talk\Events\VerifyRoomPasswordEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\SelectHelper;
 use OCA\Talk\Service\ParticipantService;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
@@ -62,6 +63,21 @@ class Room {
 	public const READ_WRITE = 0;
 	public const READ_ONLY = 1;
 
+	/**
+	 * Only visible when joined
+	 */
+	public const LISTABLE_NONE = 0;
+
+	/**
+	 * Searchable by all regular users and moderators, even when not joined, excluding users from the guest app
+	 */
+	public const LISTABLE_USERS = 1;
+
+	/**
+	 * Searchable by everyone, which includes guest users (from guest app), even when not joined
+	 */
+	public const LISTABLE_ALL = 2;
+
 	public const START_CALL_EVERYONE = 0;
 	public const START_CALL_USERS = 1;
 	public const START_CALL_MODERATORS = 2;
@@ -74,12 +90,16 @@ class Room {
 	public const EVENT_AFTER_ROOM_DELETE = self::class . '::postDeleteRoom';
 	public const EVENT_BEFORE_NAME_SET = self::class . '::preSetName';
 	public const EVENT_AFTER_NAME_SET = self::class . '::postSetName';
+	public const EVENT_BEFORE_DESCRIPTION_SET = self::class . '::preSetDescription';
+	public const EVENT_AFTER_DESCRIPTION_SET = self::class . '::postSetDescription';
 	public const EVENT_BEFORE_PASSWORD_SET = self::class . '::preSetPassword';
 	public const EVENT_AFTER_PASSWORD_SET = self::class . '::postSetPassword';
 	public const EVENT_BEFORE_TYPE_SET = self::class . '::preSetType';
 	public const EVENT_AFTER_TYPE_SET = self::class . '::postSetType';
 	public const EVENT_BEFORE_READONLY_SET = self::class . '::preSetReadOnly';
 	public const EVENT_AFTER_READONLY_SET = self::class . '::postSetReadOnly';
+	public const EVENT_BEFORE_LISTABLE_SET = self::class . '::preSetListable';
+	public const EVENT_AFTER_LISTABLE_SET = self::class . '::postSetListable';
 	public const EVENT_BEFORE_LOBBY_STATE_SET = self::class . '::preSetLobbyState';
 	public const EVENT_AFTER_LOBBY_STATE_SET = self::class . '::postSetLobbyState';
 	public const EVENT_BEFORE_SIP_ENABLED_SET = self::class . '::preSetSIPEnabled';
@@ -107,6 +127,8 @@ class Room {
 	public const EVENT_AFTER_SESSION_LEAVE_CALL = self::class . '::postSessionLeaveCall';
 	public const EVENT_BEFORE_SIGNALING_PROPERTIES = self::class . '::beforeSignalingProperties';
 
+	public const DESCRIPTION_MAXIMUM_LENGTH = 500;
+
 	/** @var Manager */
 	private $manager;
 	/** @var IDBConnection */
@@ -127,6 +149,8 @@ class Room {
 	/** @var int */
 	private $readOnly;
 	/** @var int */
+	private $listable;
+	/** @var int */
 	private $lobbyState;
 	/** @var int */
 	private $sipEnabled;
@@ -139,9 +163,13 @@ class Room {
 	/** @var string */
 	private $name;
 	/** @var string */
+	private $description;
+	/** @var string */
 	private $password;
 	/** @var int */
 	private $activeGuests;
+	/** @var int */
+	private $callFlag;
 	/** @var \DateTime|null */
 	private $activeSince;
 	/** @var \DateTime|null */
@@ -169,13 +197,16 @@ class Room {
 								int $id,
 								int $type,
 								int $readOnly,
+								int $listable,
 								int $lobbyState,
 								int $sipEnabled,
 								?int $assignedSignalingServer,
 								string $token,
 								string $name,
+								string $description,
 								string $password,
 								int $activeGuests,
+								int $callFlag,
 								\DateTime $activeSince = null,
 								\DateTime $lastActivity = null,
 								int $lastMessageId,
@@ -192,13 +223,16 @@ class Room {
 		$this->id = $id;
 		$this->type = $type;
 		$this->readOnly = $readOnly;
+		$this->listable = $listable;
 		$this->lobbyState = $lobbyState;
 		$this->sipEnabled = $sipEnabled;
 		$this->assignedSignalingServer = $assignedSignalingServer;
 		$this->token = $token;
 		$this->name = $name;
+		$this->description = $description;
 		$this->password = $password;
 		$this->activeGuests = $activeGuests;
+		$this->callFlag = $callFlag;
 		$this->activeSince = $activeSince;
 		$this->lastActivity = $lastActivity;
 		$this->lastMessageId = $lastMessageId;
@@ -220,6 +254,10 @@ class Room {
 		return $this->readOnly;
 	}
 
+	public function getListable(): int {
+		return $this->listable;
+	}
+
 	public function getLobbyState(): int {
 		$this->validateTimer();
 		return $this->lobbyState;
@@ -276,10 +314,18 @@ class Room {
 		return $this->manager->resolveRoomDisplayName($this, $userId);
 	}
 
+	public function getDescription(): string {
+		return $this->description;
+	}
+
 	public function getActiveGuests(): int {
 		return $this->activeGuests;
 	}
 
+	public function getCallFlag(): int {
+		return $this->callFlag;
+	}
+
 	public function getActiveSince(): ?\DateTime {
 		return $this->activeSince;
 	}
@@ -324,19 +370,27 @@ class Room {
 	 * Return the room properties to send to the signaling server.
 	 *
 	 * @param string $userId
+	 * @param bool $roomModified
 	 * @return array
 	 */
-	public function getPropertiesForSignaling(string $userId): array {
+	public function getPropertiesForSignaling(string $userId, bool $roomModified = true): array {
 		$properties = [
 			'name' => $this->getDisplayName($userId),
 			'type' => $this->getType(),
 			'lobby-state' => $this->getLobbyState(),
 			'lobby-timer' => $this->getLobbyTimer(),
 			'read-only' => $this->getReadOnly(),
+			'listable' => $this->getListable(),
 			'active-since' => $this->getActiveSince(),
 			'sip-enabled' => $this->getSIPEnabled(),
 		];
 
+		if ($roomModified) {
+			$properties = array_merge($properties, [
+				'description' => $this->getDescription(),
+			]);
+		}
+
 		$event = new SignalingRoomPropertiesEvent($this, $userId, $properties);
 		$this->dispatcher->dispatch(self::EVENT_BEFORE_SIGNALING_PROPERTIES, $event);
 		return $event->getProperties();
@@ -357,10 +411,10 @@ class Room {
 		}
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin('a', 'talk_sessions', 's', $query->expr()->eq('a.id', 's.attendee_id'))
 			->where($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
 			->andWhere($query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)))
@@ -393,10 +447,10 @@ class Room {
 		}
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_sessions', 's')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_sessions', 's')
 			->leftJoin('s', 'talk_attendees', 'a', $query->expr()->eq('a.id', 's.attendee_id'))
 			->where($query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)))
 			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
@@ -419,10 +473,10 @@ class Room {
 	 */
 	public function getParticipantByPin(string $pin): Participant {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin('a', 'talk_sessions', 's', $query->expr()->eq('a.id', 's.attendee_id'))
 			->andWhere($query->expr()->eq('a.pin', $query->createNamedParameter($pin)))
 			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
@@ -445,10 +499,10 @@ class Room {
 	 */
 	public function getParticipantByAttendeeId(int $attendeeId): Participant {
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin('a', 'talk_sessions', 's', $query->expr()->eq('a.id', 's.attendee_id'))
 			->andWhere($query->expr()->eq('a.id', $query->createNamedParameter($attendeeId, IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
@@ -476,10 +530,10 @@ class Room {
 		}
 
 		$query = $this->db->getQueryBuilder();
-		$query->select('*')
-			->selectAlias('a.id', 'a_id')
-			->selectAlias('s.id', 's_id')
-			->from('talk_attendees', 'a')
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
 			->leftJoin('a', 'talk_sessions', 's', $query->expr()->eq('a.id', 's.attendee_id'))
 			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)))
 			->andWhere($query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)))
@@ -540,6 +594,38 @@ class Room {
 		return true;
 	}
 
+	/**
+	 * @param string $description
+	 * @return bool True when the change was valid, false otherwise
+	 * @throws \LengthException when the given description is too long
+	 */
+	public function setDescription(string $description): bool {
+		$description = trim($description);
+
+		if (mb_strlen($description) > self::DESCRIPTION_MAXIMUM_LENGTH) {
+			throw new \LengthException('Conversation description is limited to ' . self::DESCRIPTION_MAXIMUM_LENGTH . ' characters');
+		}
+
+		$oldDescription = $this->getDescription();
+		if ($description === $oldDescription) {
+			return false;
+		}
+
+		$event = new ModifyRoomEvent($this, 'description', $description, $oldDescription);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_DESCRIPTION_SET, $event);
+
+		$query = $this->db->getQueryBuilder();
+		$query->update('talk_rooms')
+			->set('description', $query->createNamedParameter($description))
+			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+		$query->execute();
+		$this->description = $description;
+
+		$this->dispatcher->dispatch(self::EVENT_AFTER_DESCRIPTION_SET, $event);
+
+		return true;
+	}
+
 	/**
 	 * @param string $password Currently it is only allowed to have a password for Room::PUBLIC_CALL
 	 * @return bool True when the change was valid, false otherwise
@@ -584,18 +670,32 @@ class Room {
 
 	/**
 	 * @param \DateTime $since
+	 * @param int $callFlag
 	 * @param bool $isGuest
 	 * @return bool
 	 */
-	public function setActiveSince(\DateTime $since, bool $isGuest): bool {
+	public function setActiveSince(\DateTime $since, int $callFlag, bool $isGuest): bool {
 		if ($isGuest && $this->getType() === self::PUBLIC_CALL) {
 			$query = $this->db->getQueryBuilder();
 			$query->update('talk_rooms')
 				->set('active_guests', $query->createFunction($query->getColumnName('active_guests') . ' + 1'))
+				->set(
+					'call_flag',
+					$query->expr()->bitwiseOr('call_flag', $callFlag)
+				)
 				->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
 			$query->execute();
 
 			$this->activeGuests++;
+		} elseif (!$isGuest) {
+			$query = $this->db->getQueryBuilder();
+			$query->update('talk_rooms')
+				->set(
+					'call_flag',
+					$query->expr()->bitwiseOr('call_flag', $callFlag)
+				)
+				->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+			$query->execute();
 		}
 
 		if ($this->activeSince instanceof \DateTime) {
@@ -604,7 +704,7 @@ class Room {
 
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
-			->set('active_since', $query->createNamedParameter($since, 'datetime'))
+			->set('active_since', $query->createNamedParameter($since, IQueryBuilder::PARAM_DATE))
 			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->isNull('active_since'));
 		$query->execute();
@@ -625,9 +725,11 @@ class Room {
 	public function resetActiveSince(): bool {
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_rooms')
-			->set('active_guests', $query->createNamedParameter(0))
-			->set('active_since', $query->createNamedParameter(null, 'datetime'))
-			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+			->set('active_guests', $query->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->set('active_since', $query->createNamedParameter(null, IQueryBuilder::PARAM_DATE))
+			->set('call_flag', $query->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->isNotNull('active_since'));
 
 		$this->activeGuests = 0;
 		$this->activeSince = null;
@@ -683,7 +785,7 @@ class Room {
 			$query = $this->db->getQueryBuilder();
 			$query->delete('talk_attendees')
 				->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-				->andWhere($query->expr()->in('participant_type', $query->createNamedParameter([Participant::GUEST, Participant::USER_SELF_JOINED], IQueryBuilder::PARAM_INT_ARRAY)));
+				->andWhere($query->expr()->in('participant_type', $query->createNamedParameter([Participant::GUEST, Participant::GUEST_MODERATOR, Participant::USER_SELF_JOINED], IQueryBuilder::PARAM_INT_ARRAY)));
 			$query->execute();
 		}
 
@@ -729,6 +831,46 @@ class Room {
 		return true;
 	}
 
+	/**
+	 * @param int $newState New listable scope from self::LISTABLE_*
+	 * 						Also it's only allowed on rooms of type
+	 * 						`self::GROUP_CALL` and `self::PUBLIC_CALL`
+	 * @return bool True when the change was valid, false otherwise
+	 */
+	public function setListable(int $newState): bool {
+		$oldState = $this->getListable();
+		if ($newState === $oldState) {
+			return true;
+		}
+
+		if (!in_array($this->getType(), [self::GROUP_CALL, self::PUBLIC_CALL], true)) {
+			return false;
+		}
+
+		if (!in_array($newState, [
+			Room::LISTABLE_NONE,
+			Room::LISTABLE_USERS,
+			Room::LISTABLE_ALL,
+		], true)) {
+			return false;
+		}
+
+		$event = new ModifyRoomEvent($this, 'listable', $newState, $oldState);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_LISTABLE_SET, $event);
+
+		$query = $this->db->getQueryBuilder();
+		$query->update('talk_rooms')
+			->set('listable', $query->createNamedParameter($newState, IQueryBuilder::PARAM_INT))
+			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+		$query->execute();
+
+		$this->listable = $newState;
+
+		$this->dispatcher->dispatch(self::EVENT_AFTER_LISTABLE_SET, $event);
+
+		return true;
+	}
+
 	/**
 	 * @param int $newState Currently it is only allowed to change between
 	 * 						`Webinary::LOBBY_NON_MODERATORS` and `Webinary::LOBBY_NONE`
